==> nextcloud-app-tasks-0.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ro.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Sarcini care urmează",
    "Important" : "Important",
    "Today" : "Astăzi",
    "Week" : "Săptămâna",
    "All" : "Toate ",
    "Current" : "Curent",
    "Completed" : "Terminat",
    "Tasks" : "Sarcini",
    "The Tasks app for Nextcloud" : "Aplicația Tasks pentru Nextcloud",
    "Default list" : "Lista implicită",
    "Visibility of Smart Collections" : "Vizibilitatea colecțiilor inteligente",
    "Hidden" : "Ascuns",
    "Visible" : "Vizibil",
    "Automatic" : "Automat",
    "Tasks settings" : "Setările Tasks",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "No users or groups" : "Nu sunt utilizatori sau grupuri",
    "Can edit" : "Poate edita",
    "Unshare with {displayName}" : "Retrage cu {displayName}",
    "Unable to delete the share." : "Eroare la ștergerea partajării.",
    "Unable to change permissions." : "Eroare la schimbarea permisiunilor.",
    "Edit" : "Editează",
    "Copy private link" : "Copiază link privat",
    "Copied" : "Copiat",
    "Cannot copy" : "Nu s-a putut copia",
    "Export" : "Exportă",
    "Delete" : "Șterge",
    "Unshare" : "Oprește partajarea",
    "List name" : "Nume listă",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Se va șterge calendarul \"{calendar}\" și toate evenimentele și sarcinile conexe.",
    "This will unshare the calendar \"{calendar}\"." : "Se va elimina partajarea calendarului \"{calendar}\".",
    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
    "An empty name is not allowed." : "Un nume vid nu este permis.",
    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
    "Trash bin" : "Coș de gunoi",
    "Name" : "Nume",
    "Deleted" : "Șters",
    "Restore" : "Restaurare",
    "Delete permanently" : "Șterge permanent",
    "Empty trash bin" : "Golește coșul de gunoi",
    "Untitled task" : "Sarcină fără titlu",
    "Untitled event" : "Eveniment fără titlu",
    "Untitled journal" : "Jurnal fără titlu",
    "Untitled item" : "Element fără nume",
    "Unknown calendar" : "Calendar necunoscut",
    "Could not load deleted calendars and objects" : "Nu s-au putut încărca obiectele și calendarele",
    "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
    "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
    "Select a calendar" : "Selectați un calendar",
    "No calendar matches the search." : "Niciun calendar nu corespunde căutării",
    "Set date" : "Setează data",
    "Set time" : "Setează ora",
    "Delete date" : "Șterge data",
    "Click here to add a note." : "Click pentru adăugare notă.",
    "Set value" : "Setează valoarea",
    "Delete value" : "Șterge valoarea",
    "Add this as a new tag" : "Adaugă aceasta ca etichetă nouă",
    "No tag available. Create one!" : "Nu există etichete. Creați una!",
    "Create new tasks" : "Creează sarcini noi",
    "Cancel" : "Anulează",
    "Create tasks" : "Creează sarcini",
    "Close" : "Închide",
    "Select tags to filter by" : "Alege etichete după care să filtrezi",
    "Due date" : "Data scadenței",
    "Alphabetically" : "Alfabetic",
    "[Yesterday]" : "[Ieri]",
    "[Today]" : "[Astăzi]",
    "[Tomorrow]" : "[Mâine]",
    "Create task" : "Creează sarcină",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n sarcină realizată","%n sarcini realizate","%n sarcini realizate"],
    "Tomorrow" : "Mâine",
    "All day" : "Toată ziua",
    "Details" : "Detalii",
    "Select tags" : "Selectează etichete",
    "Notes" : "Notițe",
    "Reminders" : "Mementouri",
    "Repeat" : "Repetă",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "Canceled" : "Anulat",
    "Task not found!" : "Sarcina nu a fost găsită!",
    "Set start date" : "Setează data de început",
    "Set due date" : "Setează termenul limită",
    "Mark as done" : "Marchează ca efectuat",
    "An error occurred" : "A apărut o eraore",
    "Message from {author} in {conversationName}" : "Mesaj de la {author} în {conversationName}"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ro.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Sarcini care urmează",
    "Important" : "Important",
    "Today" : "Astăzi",
    "Week" : "Săptămâna",
    "All" : "Toate ",
    "Current" : "Curent",
    "Completed" : "Terminat",
    "Tasks" : "Sarcini",
    "The Tasks app for Nextcloud" : "Aplicația Tasks pentru Nextcloud",
    "Hidden" : "Ascuns",
    "Visible" : "Vizibil",
    "Automatic" : "Automat",
    "Tasks settings" : "Setările Tasks",
    "Default list" : "Lista implicită",
    "Visibility of Smart Collections" : "Vizibilitatea colecțiilor inteligente",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "No users or groups" : "Nu sunt utilizatori sau grupuri",
    "Unable to delete the share." : "Eroare la ștergerea partajării.",
    "Unable to change permissions." : "Eroare la schimbarea permisiunilor.",
    "Can edit" : "Poate edita",
    "Unshare with {displayName}" : "Retrage cu {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Se va șterge calendarul \"{calendar}\" și toate evenimentele și sarcinile conexe.",
    "This will unshare the calendar \"{calendar}\"." : "Se va elimina partajarea calendarului \"{calendar}\".",
    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
    "An empty name is not allowed." : "Un nume vid nu este permis.",
    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
    "Edit" : "Editează",
    "Copy private link" : "Copiază link privat",
    "Copied" : "Copiat",
    "Cannot copy" : "Nu s-a putut copia",
    "Export" : "Exportă",
    "Delete" : "Șterge",
    "Unshare" : "Oprește partajarea",
    "List name" : "Nume listă",
    "Untitled task" : "Sarcină fără titlu",
    "Untitled event" : "Eveniment fără titlu",
    "Untitled journal" : "Jurnal fără titlu",
    "Untitled item" : "Element fără nume",
    "Unknown calendar" : "Calendar necunoscut",
    "Could not load deleted calendars and objects" : "Nu s-au putut încărca obiectele și calendarele",
    "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
    "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
    "Empty trash bin" : "Golește coșul de gunoi",
    "Trash bin" : "Coș de gunoi",
    "Name" : "Nume",
    "Deleted" : "Șters",
    "Restore" : "Restaurare",
    "Delete permanently" : "Șterge permanent",
    "Cancel" : "Anulează",
    "Notification" : "Notificări",
    "Email" : "E-mail",
    "Audio notification" : "Notificări audio",
    "Other notification" : "Alte notificări",
    "Edit time" : "Editează ora",
    "Remove reminder" : "Elimină memento",
    "Add reminder" : "Adaugă memento",
    "Go back" : "Înapoi",
    "before at" : "Înainte de la",
    "_second_::_seconds_" : ["secundă","secunde","secunde"],
    "_minute_::_minutes_" : ["minut","minute","minute"],
    "_hour_::_hours_" : ["oră","ore","ore"],
    "_day_::_days_" : ["zi","zile","zile"],
    "_week_::_weeks_" : ["săptămână","săptămâni","săptămâni"],
    "Select a calendar" : "Selectați un calendar",
    "No calendar matches the search." : "Niciun calendar nu corespunde căutării",
    "Set date" : "Setează data",
    "Set time" : "Setează ora",
    "Delete date" : "Șterge data",
    "Click here to add a note." : "Click pentru adăugare notă.",
    "Set value" : "Setează valoarea",
    "Delete value" : "Șterge valoarea",
    "Add this as a new tag" : "Adaugă aceasta ca etichetă nouă",
    "No tag available. Create one!" : "Nu există etichete. Creați una!",
    "Create new tasks" : "Creează sarcini noi",
    "Create tasks" : "Creează sarcini",
    "Close" : "Închide",
    "Select tags to filter by" : "Alege etichete după care să filtrezi",
    "Due date" : "Data scadenței",
    "Alphabetically" : "Alfabetic",
    "Tags" : "Etichete",
    "[Yesterday]" : "[Ieri]",
    "[Today]" : "[Astăzi]",
    "[Tomorrow]" : "[Mâine]",
    "Create task" : "Creează sarcină",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n sarcină realizată","%n sarcini realizate","%n sarcini realizate"],
    "Tomorrow" : "Mâine",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "Canceled" : "Anulat",
    "Task not found!" : "Sarcina nu a fost găsită!",
    "Set start date" : "Setează data de început",
    "Set due date" : "Setează termenul limită",
    "All day" : "Toată ziua",
    "Details" : "Detalii",
    "Select tags" : "Selectează etichete",
    "Notes" : "Notițe",
    "Mark as done" : "Marchează ca efectuat",
    "An error occurred" : "A apărut o eraore",
    "Message from {author} in {conversationName}" : "Mesaj de la {author} în {conversationName}"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
